"""Beamline names definitions."""
from enum import Enum


class BeamlineName(Enum):
    """Beamline Names."""

    CARNAUBA = "carnauba"
    CATERETE = "caterete"
    CEDRO = "cedro"
    EMA = "ema"
    IMBUIA = "imbuia"
    IPE = "ipe"
    JATOBA = "jatoba"
    MANACA = "manaca"
    MOGNO = "mogno"
    PAINEIRA = "paineira"
    QUATI = "quati"
    SABIA = "sabia"
    SAPE = "sape"
    SAPUCAIA = "sapucaia"
