"""Exceptions triggered to warn about internal errors related to Assonant data parser classes."""


class AssonantDataParserError(Exception):
    """Custom Exception to warn when any error occurs inside AssonantDataParser."""
